@@ -173,7 +173,12 @@ class Firefox:
 
         import selenium
         profile = selenium.webdriver.FirefoxProfile(profile_path if profile_path and os.path.exists(profile_path) else None)
+        # https://erayerdin.com/how-to-make-selenium-load-faster-with-firefox-in-python-ck7ncjyvw00sd8ss1v4i5xob1
         profile.set_preference('browser.formfill.enable', False)
+        profile.set_preference("extensions.checkCompatibility", False) # Addon update disabled
+        profile.set_preference("extensions.checkUpdateSecurity", False)
+        profile.set_preference("extensions.update.autoUpdateEnabled", False)
+        profile.set_preference("extensions.update.enabled", False)
 
         if user_agent is not None:
             if user_agent == RANDOM_USERAGENT:
